package com.css.simulation.resource.scheduler.infrastructure.scheduler;

import api.common.pojo.constants.DictConstants;
import api.common.util.CollectionUtil;
import com.css.simulation.resource.scheduler.api.model.ProjectMessageModel;
import com.css.simulation.resource.scheduler.application.entity.ProjectWaitQueueEntity;
import com.css.simulation.resource.scheduler.application.service.ProjectService;
import com.css.simulation.resource.scheduler.domain.service.ProjectDomainService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.List;

@Component
@Slf4j
public class ProjectScheduler {
    @Resource
    private ProjectService projectService;
    @Resource
    private ProjectDomainService projectDomainService;

    /**
     * 调度项目启动
     */
    @Scheduled(fixedDelay = 5000)
    public void dispatchProject() {

        List<ProjectWaitQueueEntity> projectWaitQueue = projectDomainService.getWaitQueue();
        if (CollectionUtil.isNotEmpty(projectWaitQueue)) {
            log.info("尝试启动等待中的项目：{}", projectWaitQueue);
            for (ProjectWaitQueueEntity projectWaitQueueEntity : projectWaitQueue) {
                final String waitingType = projectWaitQueueEntity.getWaitingType();
                final ProjectMessageModel projectMessageModel = projectWaitQueueEntity.getProjectMessageModel();
                if (DictConstants.PROJECT_WAIT_TYPE_EXECUTE.equals(waitingType)) {
                    projectService.checkIfCanRun(projectMessageModel);
                }
            }
        }
    }

}
